@@ -65,6 +65,11 @@
 
 #define SECS_PER_DAY	(24 * 60 * 60)
 #define SECS_PER_WEEK	(7 * 24 * 60 * 60)
+/* These are defined here so when we link with something other than
+ * the slurmctld we will have these symbols defined.  They will get
+ * overwritten when linking with the slurmctld.
+ */
+time_t last_job_update;
 
 /*
  * These variables are required by the generic plugin interface.  If they
@@ -141,9 +146,10 @@ static int _apply_decay(double decay_factor)
 
 	slurm_mutex_lock(&assoc_mgr_association_lock);
 	itr = list_iterator_create(assoc_mgr_association_list);
+	/* We want to do this to all associations including
+	   root.  All usage_raws are calculated from the bottom up.
+	*/
 	while((assoc = list_next(itr))) {
-		if (assoc == assoc_mgr_root_assoc)
-			continue;
 		assoc->usage_raw *= decay_factor;
 		assoc->grp_used_wall *= decay_factor;
 	}
@@ -180,9 +186,10 @@ static int _reset_usage()
 
 	slurm_mutex_lock(&assoc_mgr_association_lock);
 	itr = list_iterator_create(assoc_mgr_association_list);
+	/* We want to do this to all associations including
+	   root.  All usage_raws are calculated from the bottom up.
+	*/
 	while((assoc = list_next(itr))) {
-		if (assoc == assoc_mgr_root_assoc)
-			continue;
 		assoc->usage_raw = 0;
 		assoc->grp_used_wall = 0;
 	}
@@ -781,25 +788,24 @@ static void *_decay_thread(void *no_data)
 				}
 
 				slurm_mutex_lock(&assoc_mgr_association_lock);
+				/* We want to do this all the way up
+				   to and including root.  This way we
+				   can keep track of how much usage
+				   has occured on the entire system
+				   and use that to normalize against.
+				*/
 				while(assoc) {
-					/* we don't want to make the
-					   root assoc responsible for
-					   keeping track of time
-					*/
-					if (assoc == assoc_mgr_root_assoc)
-						break;
 					assoc->grp_used_wall += run_decay;
 					assoc->usage_raw +=
 						(long double)real_decay;
 					debug4("adding %f new usage to "
 					       "assoc %u (user='%s' acct='%s') "
 					       "raw usage is now %Lf.  Group "
-					       "wall added %d making it %f.",
+					       "wall added %f making it %f.",
 					       real_decay, assoc->id,
 					       assoc->user, assoc->acct,
 					       assoc->usage_raw, run_decay,
 					       assoc->grp_used_wall);
-
 					assoc = assoc->parent_assoc_ptr;
 				}
 				slurm_mutex_unlock(&assoc_mgr_association_lock);
@@ -1033,10 +1039,10 @@ extern int priority_p_set_max_cluster_usage(uint32_t procs, uint32_t half_life)
 	last_procs = procs;
 	last_half_life = half_life;
 
-	/* get the total decay for the entire cluster */
-	assoc_mgr_root_assoc->usage_raw =
-		(long double)procs * (long double)half_life * (long double)2;
-	assoc_mgr_root_assoc->usage_norm = 1.0;
+	/* This should always be 1 and it doesn't get calculated later
+	   so set it now. usage_raw and usage_norm get calculated the
+	   same way the other associations do. */
+	assoc_mgr_root_assoc->usage_efctv = 1.0;
 	debug3("Total possible cpu usage for half_life of %d secs "
 	       "on the system is %.0Lf",
 	       half_life, assoc_mgr_root_assoc->usage_raw);
@@ -1057,10 +1063,18 @@ extern void priority_p_set_assoc_usage(acct_association_rec_t *assoc)
 	}
 
 	xassert(assoc_mgr_root_assoc);
-	xassert(assoc_mgr_root_assoc->usage_raw);
 	xassert(assoc->parent_assoc_ptr);
 
-	assoc->usage_norm = assoc->usage_raw / assoc_mgr_root_assoc->usage_raw;
+	if(assoc_mgr_root_assoc->usage_raw)
+		assoc->usage_norm =
+			assoc->usage_raw / assoc_mgr_root_assoc->usage_raw;
+	else
+		/* This should only happen when no usage has occured
+		   at all so no big deal, the other usage should be 0
+		   as well here.
+		*/
+		assoc->usage_norm = 0;
+
 	debug4("Normalized usage for %s %s off %s %Lf / %Lf = %Lf",
 	       child, child_str, assoc->parent_assoc_ptr->acct,
 	       assoc->usage_raw, assoc_mgr_root_assoc->usage_raw,
