@@ -99,6 +99,7 @@ reject_msg_t reject_msgs[REJECT_MSG_MAX];
  *	[MAXNODES=<nodes>;]		maximum number of nodes, 0 if no limit
  *	[TASKLIST=<node1:node2>;]	nodes in use, if running or completing
  *	[REJMESSAGE=<str>;]		reason job is not running, if any
+ *	[IWD=<directory>;]		Initial Working Directory
  *	UPDATETIME=<uts>;		time last active
  *	[FLAGS=INTERACTIVE;]		set if interactive (not batch) job
  *	WCLIMIT=<secs>;			wall clock time limit, seconds
@@ -320,6 +321,13 @@ static char *	_dump_job(struct job_record *job_ptr, time_t update_time)
 		xstrcat(buf, tmp);
 	}
 
+	if (!IS_JOB_FINISHED(job_ptr) && job_ptr->details &&
+	    job_ptr->details->work_dir) {
+		snprintf(tmp, sizeof(tmp), "IWD=%s;",
+			 job_ptr->details->work_dir);
+		xstrcat(buf, tmp);
+	}
+
 	if (job_ptr->batch_flag == 0)
 		xstrcat(buf, "FLAGS=INTERACTIVE;");
 
