@@ -81,14 +81,25 @@
  * the slurmctld we will have these symbols defined.  They will get
  * overwritten when linking with the slurmctld.
  */
-slurm_ctl_conf_t slurmctld_conf;
-struct node_record *node_record_table_ptr;
-List part_list;
-List job_list;
-int node_record_count;
-time_t last_node_update;
-struct switch_record *switch_record_table;
-int switch_record_cnt;
+#if defined (__APPLE__)
+	slurm_ctl_conf_t slurmctld_conf __attribute__((weak_import));
+	struct node_record *node_record_table_ptr __attribute__((weak_import));
+	List part_list __attribute__((weak_import));
+	List job_list __attribute__((weak_import));
+	int node_record_count __attribute__((weak_import));
+	time_t last_node_update __attribute__((weak_import));
+	struct switch_record *switch_record_table __attribute__((weak_import));
+	int switch_record_cnt __attribute__((weak_import));
+#else
+	slurm_ctl_conf_t slurmctld_conf;
+	struct node_record *node_record_table_ptr;
+	List part_list;
+	List job_list;
+	int node_record_count;
+	time_t last_node_update;
+	struct switch_record *switch_record_table;
+	int switch_record_cnt;
+#endif
 
 struct select_nodeinfo {
 	uint16_t magic;		/* magic number */
@@ -1127,7 +1138,7 @@ static int _job_test_topo(struct job_record *job_ptr, bitstr_t *bitmap,
 			best_fit_inx = j;
 	}
 	if (best_fit_inx == -1) {
-		error("job %u: best_fit topology failure", job_ptr->job_id);
+		debug("job %u: best_fit topology failure", job_ptr->job_id);
 		rc = EINVAL;
 		goto fini;
 	}
@@ -1329,17 +1340,22 @@ static int _rm_job_from_nodes(struct node_cr_record *node_cr_ptr,
 			break;
 		}
 		if (part_cr_ptr == NULL) {
-			if(job_ptr->part_ptr)
-				error("%s: could not find partition "
-				      "%s for node %s",
-				      pre_err, job_ptr->part_ptr->name,
-				      node_record_table_ptr[i].name);
-			else
-				error("%s: no partition ptr given for "
-				      "job %u and node %s",
-				      pre_err, job_ptr->job_id,
-				      node_record_table_ptr[i].name);
-
+			if (job_ptr->part_nodes_missing) {
+				;
+			} else if (job_ptr->part_ptr) {
+				info("%s: job %u and its partition %s "
+				     "no longer contain node %s",
+				     pre_err, job_ptr->job_id,
+				     job_ptr->partition,
+				     node_record_table_ptr[i].name);
+			} else {
+				info("%s: job %u has no pointer to partition "
+				     "%s and node %s",
+				     pre_err, job_ptr->job_id,
+				     job_ptr->partition,
+				     node_record_table_ptr[i].name);
+			}
+			job_ptr->part_nodes_missing = true;
 			rc = SLURM_ERROR;
 		}
 	}
@@ -1416,9 +1432,11 @@ static int _add_job_to_nodes(struct node_cr_record *node_cr_ptr,
 			break;
 		}
 		if (part_cr_ptr == NULL) {
-			error("%s: could not find partition %s for node %s",
-				pre_err, job_ptr->part_ptr->name,
-				node_record_table_ptr[i].name);
+			info("%s: job %u could not find partition %s for "
+			     "node %s",
+			     pre_err, job_ptr->job_id, job_ptr->part_ptr->name,
+			     node_record_table_ptr[i].name);
+			job_ptr->part_nodes_missing = true;
 			rc = SLURM_ERROR;
 		}
 	}
@@ -1616,10 +1634,11 @@ static void _init_node_cr(void)
 				break;
 			}
 			if (part_cr_ptr == NULL) {
-				error("_init_node_cr: could not find "
-					"partition %s for node %s",
-					job_ptr->partition,
-					node_record_table_ptr[i].name);
+				info("_init_node_cr: job %u could not find "
+				     "partition %s for node %s",
+				     job_ptr->job_id, job_ptr->partition,
+				     node_record_table_ptr[i].name);
+				job_ptr->part_nodes_missing = true;
 			}
 		}
 	}
