@@ -123,6 +123,8 @@ int  print_sinfo_list(List sinfo_list);
 	format_add_function(list,wid,right,suffix,_print_weight)
 #define format_add_alloc_nodes(list,wid,right,suffix) \
 	format_add_function(list,wid,right,suffix,_print_alloc_nodes)
+#define format_add_invalid(list,wid,right,suffix) \
+	format_add_function(list,wid,right,suffix,_print_com_invalid)
 
 /*****************************************************************************
  * Print Field Functions
@@ -184,5 +186,7 @@ int _print_weight(sinfo_data_t * sinfo_data, int width,
 			bool right_justify, char *suffix);
 int _print_alloc_nodes(sinfo_data_t * sinfo_data, int width,
 		       bool right_justify, char *suffix);
+int _print_com_invalid(sinfo_data_t * sinfo_data, int width,
+		       bool right_justify, char *suffix);
 
 #endif
