@@ -670,9 +670,9 @@ _process_env_var(env_vars_t *e, const char *val)
 		break;
 
 	case OPT_SIGNAL:
-		if (get_signal_opts(optarg, &opt.warn_signal,
+		if (get_signal_opts((char *)val, &opt.warn_signal,
 				    &opt.warn_time)) {
-			error("Invalid signal specification: %s", optarg);
+			error("Invalid signal specification: %s", val);
 			exit(error_exit);
 		}
 		break;
