@@ -257,12 +257,6 @@ int srun(int ac, char **av)
 	/* Set up slurmctld message handler */
 	slurmctld_msg_init();
 
-	/*
-	 *  Become --uid user
-	 */
-	if (_become_user () < 0)
-		info ("Warning: Unable to assume uid=%lu\n", opt.uid);
-
 	/* now global "opt" should be filled in and available,
 	 * create a job from opt
 	 */
@@ -349,6 +343,13 @@ int srun(int ac, char **av)
 			/* use SLURM_JOB_NAME env var */
 			opt.job_name_set_cmd = true;
 		}
+
+		/*
+		 *  Become --uid user
+		 */
+		if (_become_user () < 0)
+			info ("Warning: Unable to assume uid=%lu\n", opt.uid);
+
 		if (!job || create_job_step(job, true) < 0) {
 			slurm_complete_job(resp->job_id, 1);
 			exit(error_exit);
@@ -357,6 +358,12 @@ int srun(int ac, char **av)
 		slurm_free_resource_allocation_response_msg(resp);
 	}
 
+	/*
+	 *  Become --uid user
+	 */
+	if (_become_user () < 0)
+		info ("Warning: Unable to assume uid=%lu\n", opt.uid);
+
 	/*
 	 *  Enhance environment for job
 	 */
@@ -1326,13 +1333,18 @@ static void _handle_intr()
 	static time_t last_intr      = 0;
 	static time_t last_intr_sent = 0;
 
-	if (!opt.quit_on_intr &&
-	    (((time(NULL) - last_intr) > 1) && !opt.disable_status)) {
-		if (job->state < SRUN_JOB_FORCETERM)
+	if (!opt.quit_on_intr && ((time(NULL) - last_intr) > 1)) {
+		if  (opt.disable_status) {
+			info("sending Ctrl-C to job %u.%u",
+			     job->jobid, job->stepid);
+			slurm_step_launch_fwd_signal(job->step_ctx, SIGINT);
+		} else if (job->state < SRUN_JOB_FORCETERM) {
 			info("interrupt (one more within 1 sec to abort)");
-		else
+			task_state_print(task_state, (log_f) info);
+		} else {
 			info("interrupt (abort already in progress)");
-		task_state_print(task_state, (log_f) info);
+			task_state_print(task_state, (log_f) info);
+		}
 		last_intr = time(NULL);
 	} else  { /* second Ctrl-C in half as many seconds */
 		update_job_state(job, SRUN_JOB_CANCELLED);
